﻿#include "strdef.h"
#include "rc.h"

//
//トラックバーの作成
//hWnd...メインウィンドウのハンドル
//
//return 作成されたトラックバーのハンドル (失敗時はNULL)
//
HWND CreateTrackbar(HWND hWnd)
{
	long  lMin = 0;
	long  lMax = 20;
	long  lFirstPosition = 0;
	long  lPageSize = 5;
	HWND hTrackbar;

	/* コモンコントロールの初期化 */
	InitCommonControls();

	/* トラックバーコントロールの作成 */
	hTrackbar = CreateWindowEx(
		0, TRACKBAR_CLASS, NULL,
		WS_CHILD | WS_VISIBLE |
		TBS_NOTICKS | TBS_TOOLTIPS,
		0, 0, 200, 30,
		hWnd, (HMENU)DF_IDC_TRACKBAR, (HINSTANCE)GetWindowLongPtr(hWnd, GWLP_HINSTANCE), NULL);

	if (!hTrackbar)
		return NULL;

	/* 範囲のセット */
	SendMessageW(hTrackbar, TBM_SETRANGE, (WPARAM)TRUE, (LPARAM)MAKELONG(lMin, lMax));

	/* 1ページのサイズのセット */
	SendMessageW(hTrackbar, TBM_SETPAGESIZE, 0, (LPARAM)lPageSize);

	/* 初期値のセット */
	SendMessageW(hTrackbar, TBM_SETPOS, (WPARAM)TRUE, (LPARAM)lFirstPosition);

	/* フォーカスのセット */
//	SetFocus(hTrackbar);


	return hTrackbar;
}

//
//トラックバーに関する設定を行う
//indata...設定されるべきトラックバーのハンドル
//
void SetTrackbarStatus(InternalData indata)
{
	/* 範囲のセット */
	SendMessageW(indata.hTrack, TBM_SETRANGE, (WPARAM)TRUE, (LPARAM)MAKELONG(0, indata.maxSrc));

	/* 1ページのサイズのセット */
	SendMessageW(indata.hTrack, TBM_SETPAGESIZE, 0, (LPARAM)indata.maxSrc);
}


//
//Userに開かれるべきファイルを訪ねる
//hWnd...親ウィンドのハンドル
//temp...情報を受け取ることができる構造体
//
//return TRUE...成功 /FALSE...失敗
//
int GetFileNames(HWND hWnd, InternalData *temp)
{
	const long MAXFILELENGTH = MAX_PATH * 5;

	OPENFILENAMEW ofn;
	WCHAR fileName[MAXFILELENGTH] = { 0 };
	int iCnt = 0;
	size_t nPos;
	size_t Dirlen;

	ZeroMemory(&ofn, sizeof(ofn));
	ofn.lStructSize = sizeof(ofn);
	ofn.Flags = OFN_ALLOWMULTISELECT | OFN_EXPLORER | OFN_HIDEREADONLY;
	ofn.lpstrFile = fileName;
	ofn.nMaxFile = sizeof(fileName);
	ofn.lpstrFilter = L"全てのファイル(*.*)\0*.*\0";
	ofn.lpstrDefExt = L"*.*";
	ofn.nFilterIndex = 1;

	if (GetOpenFileNameW(&ofn))
	{
		nPos = lstrlen(fileName) + 1;

		//とりあえずディレクトリを割り出す
		Dirlen = wcslen(fileName) + 1;
		if ((temp->ParentDir = (WCHAR*)malloc(Dirlen * sizeof(WCHAR))) == NULL)
			return FALSE;
		//残りメモリも確保しておく(多くても損はしない)
		if ((temp->File = (WCHAR**)malloc(MAXFILELENGTH * sizeof(WCHAR))) == NULL)
		{
			free(temp->ParentDir);
			return FALSE;
		}

		ZeroMemory(temp->File, MAXFILELENGTH * sizeof(WCHAR));

		//データをコピー
		//(strcpy_sだとメモリをよこせと言ってくるので)
		memcpy(temp->ParentDir, fileName, Dirlen * sizeof(WCHAR));

		OutputExeLog(L"選択されたファイル名を列挙します。\n");

		if (fileName[nPos])
		{
			OutputExeLog(L"ファイルのディレクトリ:%s\\\n", temp->ParentDir);

			// 複数ファイルが選択された
			do {
				// パスをコピー
				if (fileName[nPos]) temp->File[iCnt] = (WCHAR*)malloc((wcslen(&fileName[nPos]) + 1) * sizeof(WCHAR));
				else break;
				if (!temp->File[iCnt])
				{
					//leak
					free(temp->File);
					free(temp->ParentDir);

					return FALSE;
				}
				wcscpy_s(temp->File[iCnt], (wcslen(&fileName[nPos]) + 1), &fileName[nPos]);
				OutputExeLog(L"ファイル名:%s\n", temp->File[iCnt]);
				iCnt++;
				nPos += (wcslen(&fileName[nPos]) + 1);
			} while (fileName[nPos]);
		}
		else {
			//親ディレクトリおよびファイルに関するメモリを確保しなおす
			ZeroMemory(temp->ParentDir + (Dirlen - wcslen(PathFindFileNameW(fileName)) - 2/*NULL + \\*/), sizeof(WCHAR));
			//親ディレクトリ名だけを確保
			temp->File[0] = (WCHAR*)malloc(MAXFILELENGTH * sizeof(WCHAR));
			if (!temp->File[0])
				return FALSE;
			wcscpy_s(temp->File[0], wcslen(PathFindFileNameW(fileName)) + 1, PathFindFileNameW(fileName));
			iCnt = 1;

			OutputExeLog(L"ファイルのディレクトリ:%s\\\n", temp->ParentDir);
			OutputExeLog(L"ファイル名:%s\n", temp->File[0]);
		}
	}
	else
		return FALSE;
	//準備
	temp->NowPlay = 0;
	temp->MaxPlay = iCnt;
	return TRUE;
}

//
//ボタンを作成
//hWnd...メインウィンドウのハンドル
//
//return 作成されたボタンのハンドル / 失敗時：NULL
//
HWND CreateButton(HWND hWnd)
{
	return CreateWindowW(
		L"BUTTON", L"▶",
		WS_CHILD | WS_VISIBLE | BS_PUSHBUTTON,
		0, 0, 30, 25,
		hWnd, (HMENU)BT_IDC_MCIBUTTON, (HINSTANCE)GetWindowLongPtrW(hWnd, GWLP_HINSTANCE), NULL
	);
}

//
//エディトを作成
//hWnd...メインウィンドウのハンドル
//
//return 作成されたボタンのハンドル / 失敗時：NULL
//
HWND CreateShowSecondArea(HWND hWnd)
{
	HWND hEdit;
	HFONT hFont;

	hEdit = CreateWindow(
		TEXT("EDIT"), L"00:00",
		WS_CHILD | WS_VISIBLE | WS_BORDER | ES_LEFT,
		0, 0, 200, 30, hWnd, (HMENU)1,
		(HINSTANCE)GetWindowLongPtrW(hWnd, GWLP_HINSTANCE), NULL
	);

	//
	//フォントの設定
	//

	hFont = CreateFontW(12, 0, 0, 0,
		FW_NORMAL, FALSE, FALSE, 0,
		SHIFTJIS_CHARSET,
		OUT_DEFAULT_PRECIS,
		CLIP_DEFAULT_PRECIS,
		DEFAULT_QUALITY, DEFAULT_PITCH, L"ＭＳ Ｐゴシック"
	);

	SendMessageW(hEdit, WM_SETFONT, (WPARAM)hFont, MAKELPARAM(FALSE, 0));

//	DeleteObject(hFont);

	return hEdit;
}